==> libgda-1.1.3.tar.bz2: libgda-1.1.3/providers/ibmdb2/gda-ibmdb2.h <==
/* GDA IBMDB2 Provider
 * Copyright (C) 2002 The GNOME Foundation
 *
 * AUTHORS: 
 *          Holger Thon <holger.thon@gnome-db.org>
 *          Sergey N. Belinsky <sergey_be@mail.ru>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#if !defined(__gda_ibmdb2_h__)
#  define __gda_ibmdb2_h__

#include <glib/gmacros.h>
#include <libgda/gda-intl.h>
#include <libgda/gda-connection.h>
#include <libgda/gda-server-provider.h>
#include <libgda/gda-value.h>
#include <libgda/gda-intl.h>
#include <sqlcli1.h>
#include "gda-ibmdb2-provider.h"

#define GDA_IBMDB2_PROVIDER_ID          "GDA IBMDB2 provider"

G_BEGIN_DECLS

/*
 * Utility functions
 */

GdaError *gda_ibmdb2_make_error (SQLHANDLE henv, SQLHANDLE hdbc, SQLHANDLE hstmt);
void 	  gda_ibmdb2_emit_error (GdaConnection *cnc, SQLHANDLE henv, SQLHANDLE hdbc, SQLHANDLE hstmt);
										      
G_END_DECLS

#endif

==> libgda-1.9.103.tar.bz2: libgda-1.9.103/providers/ibmdb2/gda-ibmdb2.h <==
/* GDA IBMDB2 Provider
 * Copyright (C) 2002 The GNOME Foundation
 *
 * AUTHORS: 
 *          Holger Thon <holger.thon@gnome-db.org>
 *          Sergey N. Belinsky <sergey_be@mail.ru>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#if !defined(__gda_ibmdb2_h__)
#  define __gda_ibmdb2_h__

#include <glib/gmacros.h>
#include <glib/gi18n-lib.h>
#include <libgda/gda-connection.h>
#include <libgda/gda-server-provider.h>
#include <libgda/gda-value.h>
#include <glib/gi18n-lib.h>
#include <sqlcli1.h>
#include "gda-ibmdb2-provider.h"

#define GDA_IBMDB2_PROVIDER_ID          "GDA IBMDB2 provider"

G_BEGIN_DECLS

/*
 * Utility functions
 */

GdaConnectionEvent *gda_ibmdb2_make_error (SQLHANDLE henv, SQLHANDLE hdbc, SQLHANDLE hstmt);
void 	  gda_ibmdb2_emit_error (GdaConnection *cnc, SQLHANDLE henv, SQLHANDLE hdbc, SQLHANDLE hstmt);
										      
G_END_DECLS

#endif
